@@ -215,11 +215,11 @@ int main(int argc, char *argv[])
 #endif //
 
 #ifndef BUILD_VERSION
-#define BUILD_VERSION "24.07.20251129"
+#define BUILD_VERSION "24.07.20251213"
 #endif //
 
     qDebug() << "buildVersionString: " << BUILD_VERSION;
-    qDebug() << "buildDateString: " << QString("%1 %2").arg("Nov 29 2025").arg("02:05:37");
+    qDebug() << "buildDateString: " << QString("%1 %2").arg("Dec 13 2025").arg("01:57:15");
 
     qDebug() << "buildQtVersionString: " << QString("Qt %1.%2.%3").arg(QT_VERSION_MAJOR).arg(QT_VERSION_MINOR).arg(QT_VERSION_PATCH);
     qDebug() << "runtimeQtVersionString: " << qVersion();
@@ -228,7 +228,7 @@ int main(int argc, char *argv[])
     qDebug() << "runtimeFFmpegVersionString: " << av_version_info();
 
     engine.rootContext()->setContextProperty("buildVersionString", BUILD_VERSION);
-    engine.rootContext()->setContextProperty("buildDateString", QString("%1 %2").arg("Nov 29 2025").arg("02:05:37"));
+    engine.rootContext()->setContextProperty("buildDateString", QString("%1 %2").arg("Dec 13 2025").arg("01:57:15"));
 
     engine.rootContext()->setContextProperty("buildQtVersionString", QString("Qt %1.%2.%3").arg(QT_VERSION_MAJOR).arg(QT_VERSION_MINOR).arg(QT_VERSION_PATCH));
     engine.rootContext()->setContextProperty("runtimeQtVersionString", qVersion());
